@@ -1,6 +1,8 @@
+use std::process::ExitCode;
+
 use anyhow::Result;
 use ast_grep::execute_main;
 
-fn main() -> Result<()> {
+fn main() -> Result<ExitCode> {
   execute_main()
 }
