@@ -74,6 +74,18 @@ fn test_inspect() -> Result<()> {
   Ok(())
 }
 
+#[test]
+fn test_status_code_fail_with_no_match() -> Result<()> {
+  let dir = create_test_files([("a.js", "alert(1)")])?;
+  Command::cargo_bin("ast-grep")?
+    .current_dir(dir.path())
+    .args(["-p", "no-match"])
+    .assert()
+    .failure()
+    .stdout(predicate::str::is_empty());
+  Ok(())
+}
+
 #[test]
 fn test_debug_query() -> Result<()> {
   // should not print pattern if invalid
@@ -114,7 +126,7 @@ fn test_trace_default_project() -> Result<()> {
     .current_dir(dir.path())
     .args(["-p", "alert($A)", "--inspect=summary"])
     .assert()
-    .success()
+    .failure()
     .stderr(contains("isProject=true,projectDir"));
   Ok(())
 }
@@ -126,13 +138,13 @@ fn test_trace_project() -> Result<()> {
     .current_dir(dir.path())
     .args(["-p", "alert($A)", "--inspect=summary"])
     .assert()
-    .success()
+    .failure()
     .stderr(contains("isProject=false"));
   Command::cargo_bin("ast-grep")?
     .current_dir(dir.path())
     .args(["run", "-c=not.yml", "-p", "alert($A)", "--inspect=summary"])
     .assert()
-    .success()
+    .failure()
     .stderr(contains("isProject=true,projectDir"));
   Ok(())
 }
