@@ -12,7 +12,7 @@ pub enum MatchStrictness {
   Ast,       // only ast nodes are matched
   Relaxed,   // ast-nodes excluding comments are matched
   Signature, // ast-nodes excluding comments, without text
-  Template,  // similar to smart, but node kinds are ignored, only text is matched.
+  Template,  // similar to relaxed, but node kinds are ignored, only text is matched.
 }
 
 pub(crate) enum MatchOneNode {
@@ -115,7 +115,7 @@ impl MatchStrictness {
     match self {
       M::Cst => false,
       M::Smart => true,
-      M::Ast => false,
+      M::Ast => !candidate.is_named(),
       M::Relaxed => skip_comment_or_unnamed(candidate),
       M::Signature => skip_comment_or_unnamed(candidate),
       M::Template => skip_comment(candidate),
@@ -225,4 +225,9 @@ mod test {
       )"
     ));
   }
+
+  #[test]
+  fn test_ast_trailing_comma() {
+    assert!(test_match("foo(bar)", "foo(bar,)", MatchStrictness::Ast));
+  }
 }
