@@ -1,5 +1,4 @@
 #![cfg(test)]
-use ast_grep_core::source::TSParseError;
 
 use super::*;
 
@@ -25,13 +24,13 @@ fn test_haskell_str() {
   test_non_match("$A ($B $C)", "f x y");
 }
 
-fn test_replace(src: &str, pattern: &str, replacer: &str) -> Result<String, TSParseError> {
+fn test_replace(src: &str, pattern: &str, replacer: &str) -> String {
   use crate::test::test_replace_lang;
   test_replace_lang(src, pattern, replacer, Haskell)
 }
 
 #[test]
-fn test_haskell_replace() -> Result<(), TSParseError> {
+fn test_haskell_replace() {
   let ret = test_replace(
     r#"
 fibonacci :: [Int]
@@ -40,7 +39,7 @@ fibonacci =
 "#,
     r#"$F = $$$BODY"#,
     r#"$F = undefined"#,
-  )?;
+  );
   assert_eq!(
     ret,
     r#"
@@ -56,7 +55,7 @@ flip f x y = f y x
 "#,
     r#"$F :: $A -> $B"#,
     r#"$F :: ($B) -> $A"#,
-  )?;
+  );
   assert_eq!(
     ret,
     r#"
@@ -64,5 +63,4 @@ flip :: (b -> a -> c) -> (a -> b -> c)
 flip f x y = f y x
 "#
   );
-  Ok(())
 }
